#

##

## Slide with Bullets

- Titles are formatted as Open Sans with bold applied and font size is set at 45
- Title capitalization is title case
  - Subtitle capitalization is title case
- Subtitle capitalization is title case
- Titles and subtitles should never have a period at the end

## Slide with Bullets that Build

### Subtitle Placeholder

A list where items build:

- Pressing 'h' highlights code snippets
- Pressing 'p' toggles speaker notes (if they're on the current slide)
- Pressing 'f' toggles fullscreen viewing
- Pressing 'w' toggles widescreen
- Pressing 'o' toggles overview mode
- Pressing 'ESC' toggles off these goodies

Another list, but items fade as they build:

- Hover over me!
- Hover over me!
- Hover over me!

## Slide with (Smaller Font)

- All links open in new tabs.
- To change that this, add `target="_self"` to the link.

Hidden slides are left out of the presentation.

## Code Slide (with Subtitle Placeholder)

### Subtitle Placeholder

Press 'h' to highlight important sections of code (wrapped in `<b>`).

    <script type='text/javascript'>
      // Say hello world until the user starts questioning
      // the meaningfulness of their existence.
      function helloWorld(world) {
        for (var i = 42; --i >= 0;) {
          alert('Hello ' + String(world));
        }
      }
    </script>

## Code Slide (Smaller Font)

    // Say hello world until the user starts questioning
    // the meaningfulness of their existence.
    function helloWorld(world) {
      for (var i = 42; --i >= 0;) {
        alert('Hello ' + String(world));
      }
    }

    <style>
      p { color: pink }
      b { color: blue }
    </style>

    <!DOCTYPE html>
    <html>
    <head>
      <title>My Awesome Page</title>
    </head>
    <body>
      <p>Hello world</p>
    <body>
    </html>

- Point I wanted to make #1
- Point I wanted to make #2
- Point I wanted to make #3
- Example link in notes.

Remember to say this tag line!

## Slide with Speaker Notes

Press 'p' to toggle speaker notes.

- See this amazing link: link.

Remember to say this tag line!

## Presenter Mode

Add `?presentme=true` to the URL to enabled presenter mode. This setting is sticky, meaning refreshing the page will persist presenter mode.

Hit `?presentme=false` to disable presenter mode.

## Slide with Image

## Slide with Image (Centered horz/vert)

## Table Option A

### Subtitle Placeholder

| Column 1 | Column 2 | Column 3 | Column 4
--- | --- | --- | --- | ---
Row 1 | placeholder | placeholder | placeholder | placeholder
Row 2 | placeholder | placeholder | placeholder | placeholder
Row 3 | placeholder | placeholder | placeholder | placeholder
Row 4 | placeholder | placeholder | placeholder | placeholder
Row 5 | placeholder | placeholder | placeholder | placeholder

## Table Option A (Smaller Text)

### Subtitle Placeholder

| Column 1 | Column 2 | Column 3 | Column 4
--- | --- | --- | --- | ---
Row 1 | placeholder | placeholder | placeholder | placeholder
Row 2 | placeholder | placeholder | placeholder | placeholder
Row 3 | placeholder | placeholder | placeholder | placeholder
Row 4 | placeholder | placeholder | placeholder | placeholder
Row 5 | placeholder | placeholder | placeholder | placeholder

## Table Option B

### Subtitle Placeholder

Header 1 | placeholder | placeholder | placeholder
Header 2 | placeholder | placeholder | placeholder
Header 3 | placeholder | placeholder | placeholder
Header 4 | placeholder | placeholder | placeholder
Header 5 | placeholder | placeholder | placeholder

## Slide Styles

- class="red"
- class="red2"
- class="red3"
- class="blue"
- class="blue2"
- class="blue3"
- class="green"
- class="green2"

- class="green3"
- class="yellow"
- class="yellow2"
- class="yellow3"
- class="gray"
- class="gray2"
- class="gray3"
- class="gray4"

I am centered text with a
and
button.

## Segue Slide

### Subtitle Placeholder

## Full Image (with Optional Header)

This is an example of quote text.
Name
Company

## Slide with Iframe

## <Thank You!>

Important contact information goes here.